@@ -10,25 +10,25 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.03';
-$DATE = '2004/04/13';
+$VERSION = '0.04';
+$DATE = '2004/04/17';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Data_Secs2.pm' => [qw(0.03 2004/04/13), 'revised 0.02'],
-    'MANIFEST' => [qw(0.03 2004/04/13), 'generated, replaces 0.02'],
-    'Makefile.PL' => [qw(0.03 2004/04/13), 'generated, replaces 0.02'],
-    'README' => [qw(0.03 2004/04/13), 'generated, replaces 0.02'],
-    'lib/Data/Secs2.pm' => [qw(1.16 2004/04/13), 'revised 1.15'],
-    't/Data/Secs2.d' => [qw(0.02 2004/04/13), 'revised 0.01'],
-    't/Data/Secs2.pm' => [qw(0.02 2004/04/13), 'revised 0.01'],
-    't/Data/Secs2.t' => [qw(0.03 2004/04/13), 'revised 0.02'],
-    't/Data/File/Package.pm' => [qw(1.15 2004/04/13), 'new'],
-    't/Data/File/SmartNL.pm' => [qw(1.13 2004/04/13), 'new'],
-    't/Data/Text/Scrub.pm' => [qw(1.11 2004/04/13), 'new'],
-    't/Data/Test/Tech.pm' => [qw(1.17 2004/04/13), 'new'],
-    't/Data/Data/SecsPack.pm' => [qw(0.02 2004/04/13), 'new'],
+    'lib/Docs/Site_SVD/Data_Secs2.pm' => [qw(0.04 2004/04/17), 'revised 0.03'],
+    'MANIFEST' => [qw(0.04 2004/04/17), 'generated, replaces 0.03'],
+    'Makefile.PL' => [qw(0.04 2004/04/17), 'generated, replaces 0.03'],
+    'README' => [qw(0.04 2004/04/17), 'generated, replaces 0.03'],
+    'lib/Data/Secs2.pm' => [qw(1.17 2004/04/17), 'revised 1.16'],
+    't/Data/Secs2.d' => [qw(0.03 2004/04/17), 'revised 0.02'],
+    't/Data/Secs2.pm' => [qw(0.03 2004/04/17), 'revised 0.02'],
+    't/Data/Secs2.t' => [qw(0.04 2004/04/17), 'revised 0.03'],
+    't/Data/File/Package.pm' => [qw(1.16 2004/04/17), 'unchanged'],
+    't/Data/File/SmartNL.pm' => [qw(1.13 2004/04/17), 'unchanged'],
+    't/Data/Text/Scrub.pm' => [qw(1.11 2004/04/17), 'unchanged'],
+    't/Data/Test/Tech.pm' => [qw(1.2 2004/04/17), 'revised 1.17'],
+    't/Data/Data/SecsPack.pm' => [qw(0.02 2004/04/17), 'unchanged'],
 
 );
 
@@ -53,19 +53,19 @@ use vars qw(%INVENTORY);
 
  for
 
-  File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker
+  Data::Secs2 - pack, unpack, format, transform between Perl data and SEMI E5-94 nested data
 
- Revision: B
+ Revision: C
 
- Version: 0.03
+ Version: 0.04
 
- Date: 2004/04/13
+ Date: 2004/04/17
 
  Prepared for: General Public 
 
  Prepared by:  SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>
 
- Copyright: copyright  2003 Software Diamonds
+ Copyright: copyright  2003 2004 Software Diamonds
 
  Classification: NONE
 
@@ -88,7 +88,7 @@ no matter how many nests of arrays and hashes it contains.
 
 =head2 1.3 Document overview.
 
-This document releases Data::Secs2 version 0.03
+This document releases Data::Secs2 version 0.04
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -103,7 +103,7 @@ system file specification.
 
 This document releases the file 
 
- Data-Secs2-0.03.tar.gz
+ Data-Secs2-0.04.tar.gz
 
 found at the following repository(s):
 
@@ -117,7 +117,7 @@ are as follows:
 
 =item Copyright.
 
-copyright  2003 Software Diamonds
+copyright  2003 2004 Software Diamonds
 
 =item Copyright holder contact.
 
@@ -175,19 +175,19 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Data_Secs2.pm                              0.03    2004/04/13 revised 0.02
- MANIFEST                                                     0.03    2004/04/13 generated, replaces 0.02
- Makefile.PL                                                  0.03    2004/04/13 generated, replaces 0.02
- README                                                       0.03    2004/04/13 generated, replaces 0.02
- lib/Data/Secs2.pm                                            1.16    2004/04/13 revised 1.15
- t/Data/Secs2.d                                               0.02    2004/04/13 revised 0.01
- t/Data/Secs2.pm                                              0.02    2004/04/13 revised 0.01
- t/Data/Secs2.t                                               0.03    2004/04/13 revised 0.02
- t/Data/File/Package.pm                                       1.15    2004/04/13 new
- t/Data/File/SmartNL.pm                                       1.13    2004/04/13 new
- t/Data/Text/Scrub.pm                                         1.11    2004/04/13 new
- t/Data/Test/Tech.pm                                          1.17    2004/04/13 new
- t/Data/Data/SecsPack.pm                                      0.02    2004/04/13 new
+ lib/Docs/Site_SVD/Data_Secs2.pm                              0.04    2004/04/17 revised 0.03
+ MANIFEST                                                     0.04    2004/04/17 generated, replaces 0.03
+ Makefile.PL                                                  0.04    2004/04/17 generated, replaces 0.03
+ README                                                       0.04    2004/04/17 generated, replaces 0.03
+ lib/Data/Secs2.pm                                            1.17    2004/04/17 revised 1.16
+ t/Data/Secs2.d                                               0.03    2004/04/17 revised 0.02
+ t/Data/Secs2.pm                                              0.03    2004/04/17 revised 0.02
+ t/Data/Secs2.t                                               0.04    2004/04/17 revised 0.03
+ t/Data/File/Package.pm                                       1.16    2004/04/17 unchanged
+ t/Data/File/SmartNL.pm                                       1.13    2004/04/17 unchanged
+ t/Data/Text/Scrub.pm                                         1.11    2004/04/17 unchanged
+ t/Data/Test/Tech.pm                                          1.2     2004/04/17 revised 1.17
+ t/Data/Data/SecsPack.pm                                      0.02    2004/04/17 unchanged
 
 
 =head2 3.3 Changes
@@ -202,8 +202,8 @@ Originated
 
 =item Data-Secs2-0.01
 
-Abandoned Data::Dumper in favor of L<SEMI|http://www.semi.org> E35,
-SECS-II, standard for stringifying Perl data.
+Abandoned Data::Dumper in favor of SEMI E35,
+SECS-II standard for stringifying Perl data.
 
 =item Data-Secs2-0.02
 
@@ -219,6 +219,10 @@ Coordiated with the lastest Test::STDmaker by moving the
 test library from tlib to t/Data, the same directory as the test script
 and deleting the test library File::TestPath program module.
 
+Greater expanded the subroutines to the following: arrayify, itemify, 
+listify, neuterify, scalarize, secsify, stringify, transify, vectorize.
+Added descriptions and tests for the new functions.
+
 
 =back
 
@@ -258,13 +262,13 @@ Enter one of the following repositories in a web browser:
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
 
-Right click on 'Data-Secs2-0.03.tar.gz' and download to a temporary
+Right click on 'Data-Secs2-0.04.tar.gz' and download to a temporary
 installation directory.
 Enter the following where $make is 'nmake' for microsoft
 windows; otherwise 'make'.
 
- gunzip Data-Secs2-0.03.tar.gz
- tar -xf Data-Secs2-0.03.tar
+ gunzip Data-Secs2-0.04.tar.gz
+ tar -xf Data-Secs2-0.04.tar
  perl Makefile.PL
  $make test
  $make install
@@ -369,17 +373,17 @@ Plain Old Documentation
 __DATA__
 
 DISTNAME: Data-Secs2^
-VERSION : 0.03^
+VERSION : 0.04^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.02^
-REVISION: B^
+PREVIOUS_RELEASE: 0.03^
+REVISION: C^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
-ABSTRACT: Generic file utilities originally developed to support Test::STDmaker^
-TITLE   :  File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker^
+ABSTRACT: pack, unpack, format, transform between Perl data and SEMI E5-94 SECS-II nested data^
+TITLE   :  Data::Secs2 - pack, unpack, format, transform between Perl data and SEMI E5-94 nested data^
 END_USER: General Public^
-COPYRIGHT: copyright  2003 Software Diamonds^
+COPYRIGHT: copyright  2003 2004 Software Diamonds^
 CLASSIFICATION: NONE^
 TEMPLATE:  ^
 CSS: help.css^
@@ -425,8 +429,8 @@ Originated
 
 \=item Data-Secs2-0.01
 
-Abandoned Data::Dumper in favor of L<SEMI|http://www.semi.org> E35,
-SECS-II, standard for stringifying Perl data.
+Abandoned Data::Dumper in favor of SEMI E35,
+SECS-II standard for stringifying Perl data.
 
 \=item Data-Secs2-0.02
 
@@ -442,6 +446,10 @@ Coordiated with the lastest Test::STDmaker by moving the
 test library from tlib to t/Data, the same directory as the test script
 and deleting the test library File::TestPath program module.
 
+Greater expanded the subroutines to the following: arrayify, itemify, 
+listify, neuterify, scalarize, secsify, stringify, transify, vectorize.
+Added descriptions and tests for the new functions.
+
 
 \=back
 
